Module pattern

Structs

Pattern
Represents a pattern with a fixed number of chunks.
PatternWord
Represents a variable-length word stored in a fixed-size, 16-byte buffer.

Enums

VariablePattern
Represents a pattern with a variable number of chunks.