Pattern

Struct Pattern 

pub struct Pattern<const N: usize> { /* private fields */ }
Represents a pattern with a fixed number of chunks.

Parameters

  • N - Number of pattern chunks in range [2, 6]

Implementations

Source

impl<const N: usize> Pattern<N>

pub const fn from(chunks: [u8; N]) -> Self

Construct a new Pattern from a fixed-size array.

Panics
  • If the length of chunks is not in the range [2, 6].
  • If elements of chunks is not distinct.
pub const unsafe fn from_unchecked(chunks: [u8; N]) -> Self

Construct a new Pattern from a fixed-size array, without checking.

Safety
  • The length of chunks must be in the range [2, 6]
  • Elements of chunks must be distinct.
pub fn from_bytes(chunks: impl AsRef<[u8]>) -> Option<Self>

Construct a new Pattern from a slice of bytes.

pub const fn chunks_len(&self) -> usize

pub const fn measure_encode_capacity(&self, bits: u8) -> usize

pub fn encode(&self, bits: u8) -> PatternWord

Encodes a 6-bit value into a character pattern.

The encoding distributes the bits across N chunks, where each chunk determines the repeat count for its corresponding character.

pub fn decode(&self, word: impl AsRef<str>) -> u8

Decodes a character pattern into a 6-bit value.

The decoding distributes the bits across N chunks, where each chunk determines the repeat count for its corresponding character.