seqc
0.1.0
Module pattern
Module Items
Structs
Enums
In crate seqc
seqc
Module
pattern
Structs

Pattern
Represents a pattern with a fixed number of chunks.
Pattern
Word
Represents a variable-length word stored in a fixed-size, 16-byte buffer.
Enums

Variable
Pattern
Represents a pattern with a variable number of chunks.